@@ -54,9 +54,22 @@ sub stringify {
     return "libvirt error code: " . $self->{code} . ", message: " . $self->{message} . ($self->{message} =~ /\n$/ ? "" : "\n");
 }
 
+=item my $code = $err->level
+
+Return the raw error level represented by this error. One of the
+ERROR LEVEL CONSTANTS
+
+=cut
+
+sub level {
+    my $self = shift;
+    return $self->{code}
+}
+
 =item my $code = $err->code
 
-Return the raw error code represented by this error.
+Return the raw error code represented by this error. One of the
+ERROR CODE CONSTANTS
 
 =cut
 
@@ -67,7 +80,8 @@ sub code {
 
 =item my $from = $err->domain
 
-Return the error domain raising this error.
+Return the error domain raising this error. One of the ERROR
+DOMAIN CONSTANTS
 
 =cut
 
@@ -94,7 +108,25 @@ sub message {
 
 =head1 CONSTANTS
 
-=head2 ERROR DOMAINS
+=head2 ERROR LEVEL CONSTANTS
+
+=over 4
+
+=item Sys::Virt::Error::LEVEL_NONE
+
+Undefined error level
+
+=item Sys::Virt::Error::LEVEL_WARNING
+
+Warning error level
+
+=item Sys::Virt::Error::LEVEL_ERROR
+
+Fatal error level
+
+=back
+
+=head2 ERROR DOMAIN CONSTANTS
 
 The error domain indicates which internal part of libvirt the error
 report was raised from.
@@ -284,7 +316,7 @@ The capabilities driver
 
 =back
 
-=head2 ERROR CODES
+=head2 ERROR CODE CONSTANTS
 
 The error codes allow for specific problems to be identified and
 handled separately from generic error handling.
@@ -531,6 +563,22 @@ The network interface driver is not available
 
 There are multiple interfaces with the requested MAC address
 
+=item Sys::Virt::Error::ERR_BUILD_FIREWALL
+
+The firwall could not be constructed
+
+=item Sys::Virt::Error::WAR_NO_NWFILTER
+
+The network filter driver could not be activated
+
+=item Sys::Virt::Error::ERR_NO_NWFILTER
+
+There is no network filter driver available
+
+=item Sys::Virt::Error::ERR_INVALID_NWFILTER
+
+The network filter object was invalid
+
 =item Sys::Virt::Error::WAR_NO_SECRET
 
 There secret management driver is not available
@@ -592,6 +640,14 @@ Reverting the snapshot could cause data loss
 
 The asynchronous operation was aborted at admin request
 
+=item Sys::Virt::Error::ERR_AUTH_CANCELLED
+
+The user cancelled the authentication process
+
+=item Sys::Virt::Error::ERR_NO_DOMAIN_METADATA
+
+The requested metadata does not exist
+
 =back
 
 =head1 AUTHORS
